==> nextcloud-app-calendar-1%3A5.3.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/oc.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Adieusiatz, ",
    "Open »%s«" : "Dobrir « %s »",
    "Cheers!" : "A lèu !",
    "Upcoming events" : "Eveniments venents",
    "Calendar" : "Calendièr",
    "Appointments" : "Rendetz-vos",
    "Confirm" : "Confirmar",
    "Description:" : "Descripcion :",
    "Date:" : "Data :",
    "Where:" : "Ont :",
    "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
    "Previous day" : "Jorn passat",
    "Previous week" : "Setmana passada",
    "Previous month" : "Mes passat",
    "Next day" : "Jorn seguent",
    "Next week" : "Setmana seguenta",
    "Next month" : "Mes seguent",
    "Today" : "Uèi",
    "Day" : "Jorn",
    "Week" : "Aquesta setmana",
    "Month" : "Mes",
    "Year" : "Annada",
    "List" : "Tièra",
    "Preview" : "Apercebut",
    "Copy link" : "Copiar lo ligam",
    "Edit" : "Modificar",
    "Delete" : "Suprimir",
    "Untitled calendar" : "Calendièr sens nom",
    "Calendars" : "Calendièrs",
    "Add new" : "Apondre novèl",
    "New calendar" : "Calendièr novèl",
    "Name for new calendar" : "Nom del calendièr novèl",
    "Creating calendar …" : "Creacion del calendièr…",
    "Copied link" : "Ligam copiat",
    "Export" : "Exportar",
    "Name" : "Nom",
    "Deleted" : "Suprimit",
    "Restore" : "Restaurar",
    "Delete permanently" : "Suprimir definitivament",
    "Hidden" : "Amagat",
    "Share link" : "Partejar lo ligam",
    "Copy public link" : "Copiar lo ligam public",
    "Copied code" : "Còdi copiat",
    "Could not copy code" : "Se poguèt pas copiar lo còdi",
    "Delete share link" : "Suprimir lo ligam de partatge",
    "Deleting share link …" : "Supression del ligam de partatge …",
    "can edit" : "pòt modificar",
    "Save" : "Salvar",
    "Import calendars" : "Importar de calendièrs",
    "Filename" : "Nom de fichièr",
    "Cancel" : "Anullar",
    "_Import calendar_::_Import calendars_" : ["Importar un calendièr","Importar de calendièrs"],
    "Automatic" : "Automatic",
    "Navigation" : "Navegacion",
    "Views" : "Vistas",
    "Day view" : "Mostrar un jorn",
    "Week view" : "Monstrar una setmana",
    "Month view" : "Monstrar un mes",
    "Actions" : "Accions",
    "or" : "o",
    "Show weekends" : "Monstrar las dimenjadas",
    "0 minutes" : "0 minuta",
    "Update" : "Metre a jorn",
    "Location" : "Emplaçament",
    "Description" : "Descripcion",
    "Visibility" : "Visibilitat",
    "Duration" : "Durada",
    "to" : "a",
    "Add" : "Apondre",
    "Monday" : "Diluns",
    "Tuesday" : "Dimars",
    "Wednesday" : "Dimècres",
    "Thursday" : "Dijòus",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sunday" : "Dimenge",
    "Your name" : "Vòstre nom",
    "Your email address" : "Vòstra adreça electronica",
    "Create a new conversation" : "Crear una conversacion novèla",
    "Select conversation" : "Seleccionar una conversacion",
    "on" : "lo",
    "at" : "a",
    "Reminder" : "Recòrd",
    "Notification" : "Notificacion",
    "Email" : "Adreça corrièl",
    "Audio notification" : "Notificacion àudio",
    "Other notification" : "Autras notificacions",
    "Edit time" : "Modificar l’ora",
    "Remove reminder" : "Suprimir lo rapèl",
    "+ Add reminder" : "+ Apondre un rapèl",
    "seconds" : "segondas",
    "minutes" : "minutas",
    "hours" : "oras",
    "days" : "jorns",
    "weeks" : "setmanas",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Delete file" : "Suprimir fichièr",
    "Available" : "Disponible",
    "Free" : "Liure",
    "Busy (tentative)" : "Ocupat (provisòri)",
    "Busy" : "Ocupat",
    "Out of office" : "Fòra del burèu",
    "Unknown" : "Desconegut",
    "Room name" : "Nom de la sala",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Tentative" : "Provisòri",
    "Attendees" : "Convidats",
    "Remove group" : "Suprimir lo grop",
    "Remove color" : "Suprimir la color",
    "Event title" : "Títol de l’eveniment",
    "From" : "De",
    "All day" : "Tota la jornada",
    "Repeat" : "Repetir",
    "_time_::_times_" : ["còp","còps"],
    "never" : "pas jamai",
    "after" : "aprèp",
    "first" : "primièr",
    "_day_::_days_" : ["jorn","jorns"],
    "_week_::_weeks_" : ["setmana","setmanas"],
    "_month_::_months_" : ["mes","mese"],
    "_year_::_years_" : ["annada","annadas"],
    "weekday" : "dimenjada",
    "weekend day" : "jorn de la setmana",
    "Suggestions" : "Suggestions",
    "Add resource" : "Apondre ressorsa",
    "available" : "disponible",
    "unavailable" : "indisponible",
    "Room type" : "Tipe de sala",
    "Any" : "Quina que siá",
    "from {formattedDate}" : "a partir de {formattedDate}",
    "to {formattedDate}" : "cap a {formattedDate}",
    "Pick a time" : "Causir una ora",
    "Pick a date" : "Causir una data",
    "Type to search time zone" : "Picar per cercar un fus orari",
    "Global" : "Global",
    "Subscribe" : "S'abonar",
    "Personal" : "Personal",
    "Details" : "Detalhs",
    "Untitled event" : "Eveniment sens nom",
    "Close" : "Tampar",
    "Anniversary" : "Anniversari",
    "Appointment" : "Rendetz-vos",
    "Business" : "Afar",
    "Education" : "Educacion",
    "Holiday" : "Vacanças",
    "Meeting" : "Reünion",
    "Travel" : "Viatge",
    "Vacation" : "Vacanças",
    "Daily" : "Cada jorn",
    "Weekly" : "Cada setmana",
    "Monthly" : "Cada mes",
    "Yearly" : "Cada an",
    "_Every %n day_::_Every %n days_" : ["Cada %n jorn","Cada %n jorns"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n setmana","Cada %n setmanas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n an","Cada %n ans"],
    "_%n time_::_%n times_" : ["%n còp","%n còps"],
    "second" : "segonda",
    "third" : "tresen",
    "fourth" : "quatren",
    "fifth" : "cinquen",
    "last" : "darrièr",
    "Untitled task" : "Prètzfach sens nom",
    "Other" : "Autre",
    "Add a location" : "Apondre un lòc",
    "Status" : "Estat",
    "Confirmed" : "Confirmat",
    "Canceled" : "Anullat",
    "Categories" : "Categorias",
    "Custom color" : "Color personalizada",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "User not found" : "Utilizaire pas trobat"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-calendar-1%3A6.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/oc.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Adieusiatz, ",
    "Open »%s«" : "Dobrir « %s »",
    "Cheers!" : "A lèu !",
    "Upcoming events" : "Eveniments venents",
    "Calendar" : "Calendièr",
    "Appointments" : "Rendetz-vos",
    "Confirm" : "Confirmar",
    "Description:" : "Descripcion :",
    "Date:" : "Data :",
    "Where:" : "Ont :",
    "Location:" : "Localizacion :",
    "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
    "Previous day" : "Jorn passat",
    "Previous week" : "Setmana passada",
    "Previous month" : "Mes passat",
    "Next day" : "Jorn seguent",
    "Next week" : "Setmana seguenta",
    "Next month" : "Mes seguent",
    "Today" : "Uèi",
    "Day" : "Jorn",
    "Week" : "Aquesta setmana",
    "Month" : "Mes",
    "Year" : "Annada",
    "List" : "Tièra",
    "Preview" : "Apercebut",
    "Copy link" : "Copiar lo ligam",
    "Edit" : "Modificar",
    "Delete" : "Suprimir",
    "Untitled calendar" : "Calendièr sens nom",
    "Calendars" : "Calendièrs",
    "Add new" : "Apondre novèl",
    "New calendar" : "Calendièr novèl",
    "Name for new calendar" : "Nom del calendièr novèl",
    "Creating calendar …" : "Creacion del calendièr…",
    "Copied link" : "Ligam copiat",
    "Export" : "Exportar",
    "Name" : "Nom",
    "Deleted" : "Suprimit",
    "Restore" : "Restaurar",
    "Delete permanently" : "Suprimir definitivament",
    "Share link" : "Partejar lo ligam",
    "Copy public link" : "Copiar lo ligam public",
    "Copied code" : "Còdi copiat",
    "Could not copy code" : "Se poguèt pas copiar lo còdi",
    "Delete share link" : "Suprimir lo ligam de partatge",
    "Deleting share link …" : "Supression del ligam de partatge …",
    "can edit" : "pòt modificar",
    "Save" : "Salvar",
    "View" : "Veire",
    "Import calendars" : "Importar de calendièrs",
    "Filename" : "Nom de fichièr",
    "Cancel" : "Anullar",
    "_Import calendar_::_Import calendars_" : ["Importar un calendièr","Importar de calendièrs"],
    "Automatic" : "Automatic",
    "Navigation" : "Navegacion",
    "Views" : "Vistas",
    "Day view" : "Mostrar un jorn",
    "Week view" : "Monstrar una setmana",
    "Month view" : "Monstrar un mes",
    "Actions" : "Accions",
    "or" : "o",
    "General" : "Generals",
    "Show weekends" : "Monstrar las dimenjadas",
    "Editing" : "Edicion",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "0 minutes" : "0 minuta",
    "Update" : "Metre a jorn",
    "Location" : "Emplaçament",
    "Description" : "Descripcion",
    "Visibility" : "Visibilitat",
    "Duration" : "Durada",
    "to" : "a",
    "Add" : "Apondre",
    "Monday" : "Diluns",
    "Tuesday" : "Dimars",
    "Wednesday" : "Dimècres",
    "Thursday" : "Dijòus",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sunday" : "Dimenge",
    "Your name" : "Vòstre nom",
    "Your email address" : "Vòstra adreça electronica",
    "Select conversation" : "Seleccionar una conversacion",
    "on" : "lo",
    "at" : "a",
    "Notification" : "Notificacion",
    "Email" : "Adreça corrièl",
    "Audio notification" : "Notificacion àudio",
    "Other notification" : "Autras notificacions",
    "Edit time" : "Modificar l’ora",
    "Remove reminder" : "Suprimir lo rapèl",
    "seconds" : "segondas",
    "minutes" : "minutas",
    "hours" : "oras",
    "days" : "jorns",
    "weeks" : "setmanas",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Delete file" : "Suprimir fichièr",
    "Available" : "Disponible",
    "Out of office" : "Fòra del burèu",
    "Room name" : "Nom de la sala",
    "Free" : "Liure",
    "Busy (tentative)" : "Ocupat (provisòri)",
    "Busy" : "Ocupat",
    "Unknown" : "Desconegut",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Tentative" : "Provisòri",
    "Attendees" : "Convidats",
    "Remove group" : "Suprimir lo grop",
    "Remove color" : "Suprimir la color",
    "Event title" : "Títol de l’eveniment",
    "From" : "De",
    "Repeat" : "Repetir",
    "_time_::_times_" : ["còp","còps"],
    "never" : "pas jamai",
    "after" : "aprèp",
    "first" : "primièr",
    "_day_::_days_" : ["jorn","jorns"],
    "_week_::_weeks_" : ["setmana","setmanas"],
    "_month_::_months_" : ["mes","mese"],
    "_year_::_years_" : ["annada","annadas"],
    "weekday" : "dimenjada",
    "weekend day" : "jorn de la setmana",
    "Add resource" : "Apondre ressorsa",
    "available" : "disponible",
    "unavailable" : "indisponible",
    "Room type" : "Tipe de sala",
    "Any" : "Quina que siá",
    "Remove participant" : "Tirar participant",
    "Yes" : "Òc",
    "No" : "Non",
    "None" : "Cap",
    "Create" : "Crear",
    "from {formattedDate}" : "a partir de {formattedDate}",
    "to {formattedDate}" : "cap a {formattedDate}",
    "Pick a time" : "Causir una ora",
    "Pick a date" : "Causir una data",
    "Type to search time zone" : "Picar per cercar un fus orari",
    "Global" : "Global",
    "Subscribe" : "S'abonar",
    "Personal" : "Personal",
    "Edit event" : "Editar un eveniment",
    "All day" : "Tota la jornada",
    "Untitled event" : "Eveniment sens nom",
    "Close" : "Tampar",
    "Selected" : "Seleccionat",
    "Title" : "Títol",
    "30 min" : "30 min",
    "Participants" : "Participants",
    "Submit" : "Transmetre",
    "Anniversary" : "Anniversari",
    "Appointment" : "Rendetz-vos",
    "Business" : "Afar",
    "Education" : "Educacion",
    "Holiday" : "Vacanças",
    "Meeting" : "Reünion",
    "Travel" : "Viatge",
    "Vacation" : "Vacanças",
    "Daily" : "Cada jorn",
    "Weekly" : "Cada setmana",
    "Monthly" : "Cada mes",
    "Yearly" : "Cada an",
    "_Every %n day_::_Every %n days_" : ["Cada %n jorn","Cada %n jorns"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n setmana","Cada %n setmanas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n an","Cada %n ans"],
    "_%n time_::_%n times_" : ["%n còp","%n còps"],
    "second" : "segonda",
    "third" : "tresen",
    "fourth" : "quatren",
    "fifth" : "cinquen",
    "last" : "darrièr",
    "Untitled task" : "Prètzfach sens nom",
    "Other" : "Autre",
    "Add a location" : "Apondre un lòc",
    "Status" : "Estat",
    "Confirmed" : "Confirmat",
    "Canceled" : "Anullat",
    "Categories" : "Categorias",
    "Custom color" : "Color personalizada",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "User not found" : "Utilizaire pas trobat",
    "Hidden" : "Amagat"
},
"nplurals=2; plural=(n > 1);");
